@@ -46,18 +46,8 @@ const char* kFetchGroupsUrl = "api2/groups/";
 const char* kRemoteWipeReportUrl = "api2/device-wiped/";
 const char* kSearchUsersUrl = "api2/search-user/";
 
-const char* kLatestVersionUrl = "https://seafile.com/api/client-versions/";
-
 const char* kGetThumbnailUrl = "api2/repos/%1/thumbnail/";
 
-#if defined(Q_OS_WIN32)
-const char* kOsName = "windows";
-#elif defined(Q_OS_LINUX)
-const char* kOsName = "linux";
-#else
-const char* kOsName = "mac";
-#endif
-
 } // namespace
 
 
@@ -439,39 +429,6 @@ void CreateDefaultRepoRequest::requestSuccess(QNetworkReply& reply)
     emit success(dict.value("repo_id").toString());
 }
 
-GetLatestVersionRequest::GetLatestVersionRequest(const QString& client_id,
-                                                 const QString& client_version)
-    : SeafileApiRequest(QUrl(kLatestVersionUrl), SeafileApiRequest::METHOD_GET)
-{
-    setUrlParam("id", client_id.left(8));
-    setUrlParam("v", QString(kOsName) + "-" + client_version);
-}
-
-void GetLatestVersionRequest::requestSuccess(QNetworkReply& reply)
-{
-    json_error_t error;
-    json_t* root = parseJSON(reply, &error);
-    if (!root) {
-        qWarning("GetLatestVersionRequest: failed to parse json:%s\n",
-                 error.text);
-        emit failed(ApiError::fromJsonError());
-        return;
-    }
-
-    QScopedPointer<json_t, JsonPointerCustomDeleter> json(root);
-
-    QMap<QString, QVariant> dict = mapFromJSON(json.data(), &error);
-
-    if (dict.contains(kOsName)) {
-        QString version = dict.value(kOsName).toString();
-        qWarning("The latest version is %s", toCStr(version));
-        emit success(version);
-        return;
-    }
-
-    emit failed(ApiError::fromJsonError());
-}
-
 GetStarredFilesRequest::GetStarredFilesRequest(const Account& account)
     : SeafileApiRequest(account.getAbsoluteUrl(kStarredFilesUrl),
                         SeafileApiRequest::METHOD_GET,
@@ -886,7 +843,7 @@ void FetchAccountInfoRequest::requestSuccess(QNetworkReply& reply)
 PrivateShareRequest::PrivateShareRequest(const Account& account,
                                          const QString& repo_id,
                                          const QString& path,
-                                         const QString& username,
+                                         const SeafileUser& user,
                                          int group_id,
                                          SharePermission permission,
                                          ShareType share_type,
@@ -897,7 +854,7 @@ PrivateShareRequest::PrivateShareRequest(const Account& account,
                                                                  : METHOD_PUT),
           account.token),
       group_id_(share_type == SHARE_TO_GROUP ? group_id : -1),
-      username_(share_type == SHARE_TO_USER ? username : QString()),
+      user_(share_type == SHARE_TO_USER ? user: SeafileUser()),
       permission_(permission),
       share_type_(share_type),
       share_operation_(op)
@@ -916,10 +873,10 @@ PrivateShareRequest::PrivateShareRequest(const Account& account,
 
     if (share_type == SHARE_TO_USER) {
         if (is_add) {
-            setFormParam("username", username);
+            setFormParam("username", user_.email);
         }
         else {
-            setUrlParam("username", username);
+            setUrlParam("username", user_.email);
         }
     }
     else {
