@@ -238,23 +238,6 @@ private:
     Q_DISABLE_COPY(CreateDefaultRepoRequest);
 };
 
-class GetLatestVersionRequest : public SeafileApiRequest
-{
-    Q_OBJECT
-public:
-    GetLatestVersionRequest(const QString& client_id,
-                            const QString& client_version);
-
-signals:
-    void success(const QString& latest_version);
-
-protected slots:
-    void requestSuccess(QNetworkReply& reply);
-
-private:
-    Q_DISABLE_COPY(GetLatestVersionRequest);
-};
-
 class GetStarredFilesRequest : public SeafileApiRequest
 {
     Q_OBJECT
@@ -559,7 +542,7 @@ public:
     PrivateShareRequest(const Account& account,
                         const QString& repo_id,
                         const QString& path,
-                        const QString& username,
+                        const SeafileUser& user,
                         int group_id,
                         SharePermission permission,
                         ShareType share_type,
@@ -575,9 +558,9 @@ public:
         return share_type_ == SHARE_TO_GROUP ? group_id_ : -1;
     };
 
-    QString userName() const
+    SeafileUser user() const
     {
-        return share_type_ == SHARE_TO_USER ? username_ : QString();
+        return share_type_ == SHARE_TO_USER ? user_ : SeafileUser();
     };
 
     SharePermission permission() const
@@ -600,7 +583,7 @@ private:
     Q_DISABLE_COPY(PrivateShareRequest);
 
     int group_id_;
-    QString username_;
+    SeafileUser user_;
     SharePermission permission_;
     ShareType share_type_;
     ShareOperation share_operation_;
@@ -739,5 +722,3 @@ private:
 };
 
 #endif // SEAFILE_CLIENT_API_REQUESTS_H
-
-
