@@ -92,17 +92,17 @@ FileBrowserDialog::FileBrowserDialog(const Account &account, const ServerRepo& r
     }
     setWindowTitle(title);
     setWindowIcon(QIcon(":/images/seafile.png"));
-    setWindowFlags((windowFlags() & ~Qt::WindowContextHelpButtonHint & ~Qt::Dialog)
-#if !defined(Q_OS_MAC)
-                   | Qt::FramelessWindowHint
-#endif
-                   | Qt::Window);
 
-    resizer_ = new QSizeGrip(this);
-    resizer_->resize(resizer_->sizeHint());
-    setAttribute(Qt::WA_TranslucentBackground, true);
+    Qt::WindowFlags flags =
+        (windowFlags() & ~Qt::WindowContextHelpButtonHint & ~Qt::Dialog) |
+        Qt::Window | Qt::WindowSystemMenuHint | Qt::CustomizeWindowHint |
+        Qt::WindowMinimizeButtonHint | Qt::WindowCloseButtonHint |
+        Qt::WindowMaximizeButtonHint;
+
+    setWindowFlags(flags);
+
+    // setAttribute(Qt::WA_TranslucentBackground, true);
 
-    createTitleBar();
     createToolBar();
     createStatusBar();
     createLoadingFailedView();
@@ -127,15 +127,10 @@ FileBrowserDialog::FileBrowserDialog(const Account &account, const ServerRepo& r
     stack_->insertWidget(INDEX_LOADING_FAILED_VIEW, loading_failed_view_);
     stack_->setContentsMargins(0, 0, 0, 0);
 
-    vlayout->addWidget(header_);
     vlayout->addWidget(toolbar_);
     vlayout->addWidget(stack_);
     vlayout->addWidget(status_bar_);
 
-#ifdef Q_OS_MAC
-    header_->setVisible(false);
-#endif
-
     // this <--> table_view_
     connect(table_view_, SIGNAL(direntClicked(const SeafDirent&)),
             this, SLOT(onDirentClicked(const SeafDirent&)));
@@ -234,42 +229,6 @@ void FileBrowserDialog::init()
     enterPath(current_path_);
 }
 
-void FileBrowserDialog::createTitleBar()
-{
-    header_ = new QWidget;
-    header_->setObjectName("mHeader");
-    QHBoxLayout *layout = new QHBoxLayout;
-    layout->setContentsMargins(1, 1, 1, 1);
-    layout->setSpacing(0);
-    header_->setLayout(layout);
-
-    QSpacerItem *spacer1 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);
-    layout->addSpacerItem(spacer1);
-
-    brand_label_ = new QLabel(windowTitle());
-    brand_label_->setObjectName("mBrand");
-    layout->addWidget(brand_label_);
-
-    QSpacerItem *spacer2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);
-    layout->addSpacerItem(spacer2);
-
-    minimize_button_ = new QPushButton;
-    minimize_button_->setObjectName("mMinimizeBtn");
-    minimize_button_->setToolTip(tr("Minimize"));
-    minimize_button_->setIcon(awesome->icon(icon_minus, QColor("#808081")));
-    layout->addWidget(minimize_button_);
-    connect(minimize_button_, SIGNAL(clicked()), this, SLOT(showMinimized()));
-
-    close_button_ = new QPushButton;
-    close_button_->setObjectName("mCloseBtn");
-    close_button_->setToolTip(tr("Close"));
-    close_button_->setIcon(awesome->icon(icon_remove, QColor("#808081")));
-    layout->addWidget(close_button_);
-    connect(close_button_, SIGNAL(clicked()), this, SLOT(close()));
-
-    header_->installEventFilter(this);
-}
-
 void FileBrowserDialog::createToolBar()
 {
     toolbar_ = new QToolBar;
@@ -362,12 +321,6 @@ void FileBrowserDialog::createStatusBar()
     refresh_action_->setShortcut(QKeySequence::Refresh);
     status_bar_->addAction(refresh_action_);
 
-    open_cache_dir_action_ = new QAction(this);
-    open_cache_dir_action_->setIcon(QIcon(":/images/toolbar/file.png"));
-    open_cache_dir_action_->setToolTip(tr("Open the cache folder"));
-    connect(open_cache_dir_action_, SIGNAL(triggered()), this, SLOT(openCacheFolder()));
-    status_bar_->addAction(open_cache_dir_action_);
-
     QWidget *spacer2 = new QWidget;
     spacer2->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Preferred);
     status_bar_->addWidget(spacer2);
@@ -939,16 +892,6 @@ void FileBrowserDialog::chooseDirectoryToUpload()
     uploadOrUpdateFile(path);
 }
 
-void FileBrowserDialog::openCacheFolder()
-{
-    QString folder =
-      ::pathJoin(data_mgr_->getRepoCacheFolder(repo_.id), current_path_);
-    if (!::createDirIfNotExists(folder))
-        seafApplet->warningBox(tr("Unable to create cache folder"), this);
-    if (!QDesktopServices::openUrl(QUrl::fromLocalFile(folder)))
-        seafApplet->warningBox(tr("Unable to open cache folder"), this);
-}
-
 void FileBrowserDialog::onNavigatorClick(int id)
 {
     // calculate the path
@@ -1141,28 +1084,6 @@ void FileBrowserDialog::onCancelDownload(const SeafDirent& dirent)
         ::pathJoin(current_path_, dirent.name));
 }
 
-bool FileBrowserDialog::eventFilter(QObject *obj, QEvent *event)
-{
-    if (obj == header_) {
-        if (event->type() == QEvent::MouseButtonPress) {
-            QMouseEvent *ev = (QMouseEvent *)event;
-            QRect frame_rect = frameGeometry();
-            old_pos_ = ev->globalPos() - frame_rect.topLeft();
-            return true;
-        } else if (event->type() == QEvent::MouseMove) {
-            QMouseEvent *ev = (QMouseEvent *)event;
-            move(ev->globalPos() - old_pos_);
-            return true;
-        }
-    }
-    return QDialog::eventFilter(obj, event);
-}
-
-void FileBrowserDialog::resizeEvent(QResizeEvent *event)
-{
-    resizer_->move(rect().bottomRight() - resizer_->rect().bottomRight());
-    resizer_->raise();
-}
 
 void FileBrowserDialog::done(int retval)
 {
