@@ -476,7 +476,7 @@ void FileTableView::contextMenuEvent(QContextMenuEvent *event)
             }
         }
 
-        download_action_->setVisible(true);
+        download_action_->setVisible(!has_dir);
         saveas_action_->setText(tr("&Save As To..."));
         saveas_action_->setEnabled(!has_dir);
         download_action_->setText(tr("D&ownload"));
@@ -511,6 +511,7 @@ void FileTableView::contextMenuEvent(QContextMenuEvent *event)
     update_action_->setVisible(true);
     cancel_download_action_->setVisible(true);
     download_action_->setVisible(true);
+    download_action_->setEnabled(true);
     cancel_download_action_->setVisible(false);
     if (item_->readonly) {
         move_action_->setEnabled(false);
@@ -1093,3 +1094,19 @@ void FileTableModel::updateThumbnail(const QPixmap& thumbnail, const QString& pa
             break;
         }
 }
+
+bool FileTableSortFilterProxyModel::lessThan(const QModelIndex &left, const QModelIndex &right) const
+{
+    bool is_dir_left = source_model_->direntAt(left.row())->isDir();
+    bool is_dir_right = source_model_->direntAt(right.row())->isDir();
+    if (is_dir_left != is_dir_right)
+        return sortOrder() != Qt::AscendingOrder ? is_dir_right
+                                                 : !is_dir_right;
+    else {
+        const QString left_name = source_model_->direntAt(left.row())->name;
+        const QString right_name = source_model_->direntAt(right.row())->name;
+        return digitalCompare(left_name, right_name) < 0 ? true : false;
+    }
+
+    return QSortFilterProxyModel::lessThan(left, right);
+}
