@@ -32,7 +32,6 @@
 #include "open-local-helper.h"
 #include "avatar-service.h"
 #include "filebrowser/thumbnail-service.h"
-#include "seahub-notifications-monitor.h"
 #include "filebrowser/data-cache.h"
 #include "filebrowser/auto-update-mgr.h"
 #include "rpc/local-repo.h"
@@ -42,12 +41,17 @@
 #include "customization-service.h"
 
 #if defined(Q_OS_WIN32)
-#include "ext-handler.h"
-#include "utils/registry.h"
+    #include "ext-handler.h"
+    #include "utils/registry.h"
 #elif defined(HAVE_FINDER_SYNC_SUPPORT)
-#include "finder-sync/finder-sync-listener.h"
+    #include "finder-sync/finder-sync-listener.h"
 #endif
 
+#ifdef HAVE_SPARKLE_SUPPORT
+#include "auto-update-service.h"
+#endif
+
+
 #if defined(Q_OS_MAC)
 #include "utils/utils-mac.h"
 #endif
@@ -137,46 +141,6 @@ void myLogHandler(QtMsgType type, const QMessageLogContext &context, const QStri
     }
 }
 
-/**
- * s1 > s2 --> *ret = 1
- *    = s2 --> *ret = 0
- *    < s2 --> *ret = -1
- *
- * If any of the vesion strings is invalid, return -1; else return 0
- */
-int compareVersions(const QString& s1, const QString& s2, int *ret)
-{
-    QStringList v1 = s1.split(".");
-    QStringList v2 = s2.split(".");
-
-    int i = 0;
-    while (i < v1.size() && i < v2.size()) {
-        bool ok;
-        int a = v1[i].toInt(&ok);
-        if (!ok) {
-            return -1;
-        }
-        int b = v2[i].toInt(&ok);
-        if (!ok) {
-            return -1;
-        }
-
-        if (a > b) {
-            *ret = 1;
-            return 0;
-        } else if (a < b) {
-            *ret = -1;
-            return 0;
-        }
-
-        i++;
-    }
-
-    *ret = v1.size() - v2.size();
-
-    return 0;
-}
-
 #ifdef Q_OS_MAC
 void writeCABundleForCurl()
 {
@@ -213,9 +177,6 @@ const char *const kSeafilePreconfigureGroupName = "preconfigure";
 
 const int kIntervalForUpdateRepoProperty = 1000;
 
-const char *kSeafileClientDownloadUrl = "https://seafile.com/en/download/";
-const char *kSeafileClientDownloadUrlChinese = "https://seafile.com/download/";
-
 const char *kRepoServerUrlProperty = "server-url";
 const char *kRepoRelayAddrProperty = "relay-address";
 
@@ -262,6 +223,11 @@ SeafileApplet::~SeafileApplet()
         delete main_win_;
 #if defined(Q_OS_WIN32)
     SeafileExtensionHandler::instance()->stop();
+
+#ifdef HAVE_SPARKLE_SUPPORT
+    AutoUpdateService::instance()->stop();
+#endif
+
 #endif
 }
 
@@ -323,13 +289,11 @@ void SeafileApplet::onDaemonStarted()
     // start network-related services
     //
     NetworkStatusDetector::instance()->start();
-    FileCacheDB::instance()->start();
     AutoUpdateManager::instance()->start();
 
     AvatarService::instance()->start();
     ThumbnailService::instance()->start();
 
-    SeahubNotificationsMonitor::instance()->start();
     ServerStatusService::instance()->start();
     CustomizationService::instance()->start();
     AccountInfoService::instance()->start();
@@ -383,10 +347,6 @@ void SeafileApplet::onDaemonStarted()
     configurator_->installCustomUrlHandler();
 #endif
 
-    if (settings_mgr_->isCheckLatestVersionEnabled()) {
-        checkLatestVersionInfo();
-    }
-
     QString value;
     if (seafApplet->rpcClient()->seafileGetConfig("client_name", &value) < 0 || value.isEmpty()) {
         // We do this because clients before 6.0 don't set the "client_name" option.
@@ -407,6 +367,12 @@ void SeafileApplet::onDaemonStarted()
 #elif defined(HAVE_FINDER_SYNC_SUPPORT)
     finderSyncListenerStart();
 #endif
+
+#ifdef HAVE_SPARKLE_SUPPORT
+    if (AutoUpdateService::instance()->shouldSupportAutoUpdate()) {
+        AutoUpdateService::instance()->start();
+    }
+#endif
 }
 
 void SeafileApplet::checkInitVDrive()
@@ -621,48 +587,6 @@ bool SeafileApplet::detailedYesOrNoBox(const QString& msg, const QString& detail
     return msgBox.exec() == QMessageBox::Yes;
 }
 
-void SeafileApplet::checkLatestVersionInfo()
-{
-    QString id = rpc_client_->getCcnetPeerId();
-    QString version = STRINGIZE(SEAFILE_CLIENT_VERSION);
-
-    GetLatestVersionRequest *req = new GetLatestVersionRequest(id, version);
-    req->send();
-
-    connect(req, SIGNAL(success(const QString&)),
-            this, SLOT(onGetLatestVersionInfoSuccess(const QString&)));
-}
-
-void SeafileApplet::onGetLatestVersionInfoSuccess(const QString& latest_version)
-{
-    QString current_version = STRINGIZE(SEAFILE_CLIENT_VERSION);
-
-    int ret;
-    if (compareVersions(current_version, latest_version, &ret) < 0) {
-        return;
-    }
-
-    if (ret >= 0) {
-        return;
-    }
-
-    QString msg = tr("A new version of %1 client (%2) is available.\n"
-                     "Do you want to visit the download page?").arg(getBrand()).arg(latest_version);
-
-    if (!yesOrNoBox(msg, NULL, true)) {
-        return;
-    }
-
-    QString url;
-    if (QLocale::system().name() == "zh_CN") {
-        url = kSeafileClientDownloadUrlChinese;
-    } else {
-        url = kSeafileClientDownloadUrl;
-    }
-
-    QDesktopServices::openUrl(url);
-}
-
 /**
  * For each repo, add the "server-url" property (inferred from account url),
  * which would be used for http sync.
