@@ -29,7 +29,6 @@ namespace
 {
 const char *kHideMainWindowWhenStarted = "hideMainWindowWhenStarted";
 const char *kHideDockIcon = "hideDockIcon";
-const char *kCheckLatestVersion = "checkLatestVersion";
 const char *kEnableSyncingWithExistingFolder = "syncingWithExistingFolder";
 const char *kBehaviorGroup = "Behavior";
 
@@ -386,33 +385,6 @@ void SettingsManager::removeAllSettings()
 #endif
 }
 
-void SettingsManager::setCheckLatestVersionEnabled(bool enabled)
-{
-    QSettings settings;
-
-    settings.beginGroup(kBehaviorGroup);
-    settings.setValue(kCheckLatestVersion, enabled);
-    settings.endGroup();
-}
-
-bool SettingsManager::isCheckLatestVersionEnabled()
-{
-    QString brand = getBrand();
-
-    if (brand != "Seafile") {
-        return false;
-    }
-
-    QSettings settings;
-    bool enabled;
-
-    settings.beginGroup(kBehaviorGroup);
-    enabled = settings.value(kCheckLatestVersion, true).toBool();
-    settings.endGroup();
-
-    return enabled;
-}
-
 void SettingsManager::setAllowInvalidWorktree(bool val)
 {
     if (allow_invalid_worktree_ != val) {
