@@ -8,6 +8,7 @@
 #include <QMouseEvent>
 #include <QUrl>
 #include <QUrlQuery>
+#include <QThreadPool>
 
 #include "account.h"
 #include "seafile-applet.h"
@@ -28,6 +29,7 @@
 #include "filebrowser/file-browser-manager.h"
 #include "api/api-error.h"
 #include "api/requests.h"
+#include "filebrowser/auto-update-mgr.h"
 
 #include "account-view.h"
 namespace {
@@ -108,8 +110,14 @@ void AccountView::deleteAccount()
         return;
     Account account = qvariant_cast<Account>(action->data());
 
-    QString question = tr("Are you sure to remove account from \"%1\"?<br>"
-                          "<b>Warning: All libraries of this account would be unsynced!</b>").arg(account.serverUrl.toString());
+    // QString question = tr("Are you sure to remove account from \"%1\"?<br>"
+    //                       "<b>Warning: All libraries of this account would be unsynced!</b>").arg(account.serverUrl.toString());
+
+    QString question = tr("Are you sure you want to remove account %1?<br><br>"
+                          "The account will be removed locally. All syncing "
+                          "configuration will be removed too. The account at "
+                          "the server will not be affected.")
+                           .arg(account.username);
 
     if (seafApplet->yesOrNoBox(question, this, false)) {
         FileBrowserManager::getInstance()->closeAllDialogByAccount(account);
@@ -379,6 +387,8 @@ void AccountView::toggleAccount()
         return;
     }
 
+    AutoUpdateManager::instance()->cleanCachedFile();
+
     // logout Account
     FileBrowserManager::getInstance()->closeAllDialogByAccount(account);
     LogoutDeviceRequest *req = new LogoutDeviceRequest(account);
@@ -424,6 +434,7 @@ void AccountView::onLogoutDeviceRequestSuccess()
         return;
     }
     seafApplet->accountManager()->clearAccountToken(account);
+
     req->deleteLater();
 }
 
