@@ -28,7 +28,6 @@ extern "C" {
 #include "main-window.h"
 #include "settings-dialog.h"
 #include "settings-mgr.h"
-#include "seahub-notifications-monitor.h"
 #include "server-status-service.h"
 #include "api/commit-details.h"
 #include "sync-errors-dialog.h"
@@ -48,6 +47,8 @@ extern void qt_mac_set_dock_menu(QMenu *menu);
 #include <QDBusPendingCall>
 #endif
 
+#include "src/ui/about-dialog.h"
+
 namespace {
 
 const int kRefreshInterval = 1000;
@@ -114,7 +115,8 @@ SeafileTrayIcon::SeafileTrayIcon(QObject *parent)
       rotate_counter_(0),
       state_(STATE_DAEMON_UP),
       next_message_msec_(0),
-      sync_errors_dialog_(nullptr)
+      sync_errors_dialog_(nullptr),
+      about_dialog_(nullptr)
 {
     setState(STATE_DAEMON_DOWN);
     rotate_timer_ = new QTimer(this);
@@ -133,9 +135,6 @@ SeafileTrayIcon::SeafileTrayIcon(QObject *parent)
     connect(this, SIGNAL(activated(QSystemTrayIcon::ActivationReason)),
             this, SLOT(onActivated(QSystemTrayIcon::ActivationReason)));
 
-    connect(SeahubNotificationsMonitor::instance(), SIGNAL(notificationsChanged()),
-            this, SLOT(onSeahubNotificationsChanged()));
-
 #if !defined(Q_OS_LINUX)
     connect(this, SIGNAL(messageClicked()),
             this, SLOT(onMessageClicked()));
@@ -166,10 +165,6 @@ void SeafileTrayIcon::createActions()
     enable_auto_sync_action_ = new QAction(tr("Enable auto sync"), this);
     connect(enable_auto_sync_action_, SIGNAL(triggered()), this, SLOT(enableAutoSync()));
 
-    view_unread_seahub_notifications_action_ = new QAction(tr("View unread notifications"), this);
-    connect(view_unread_seahub_notifications_action_, SIGNAL(triggered()),
-            this, SLOT(viewUnreadNotifications()));
-
     quit_action_ = new QAction(tr("&Quit"), this);
     connect(quit_action_, SIGNAL(triggered()), this, SLOT(quitSeafile()));
 
@@ -207,7 +202,6 @@ void SeafileTrayIcon::createContextMenu()
     // help_menu_->addAction(open_help_action_);
 
     context_menu_ = new QMenu(NULL);
-    context_menu_->addAction(view_unread_seahub_notifications_action_);
     context_menu_->addAction(show_main_window_action_);
     context_menu_->addAction(open_seafile_folder_action_);
     context_menu_->addAction(settings_action_);
@@ -236,8 +230,6 @@ void SeafileTrayIcon::prepareContextMenu()
         enable_auto_sync_action_->setVisible(true);
         disable_auto_sync_action_->setVisible(false);
     }
-
-    view_unread_seahub_notifications_action_->setVisible(state_ == STATE_HAVE_UNREAD_MESSAGE);
 }
 
 void SeafileTrayIcon::createGlobalMenuBar()
@@ -247,7 +239,6 @@ void SeafileTrayIcon::createGlobalMenuBar()
 #ifdef Q_OS_MAC
     // create qmenu used in menubar and docker menu
     global_menu_ = new QMenu(tr("File"));
-    global_menu_->addAction(view_unread_seahub_notifications_action_);
     global_menu_->addAction(show_main_window_action_);
     global_menu_->addAction(open_seafile_folder_action_);
     global_menu_->addAction(settings_action_);
@@ -488,14 +479,22 @@ void SeafileTrayIcon::showMainWindow()
 
 void SeafileTrayIcon::about()
 {
-    QMessageBox::about(seafApplet->mainWindow(), tr("About %1").arg(getBrand()),
-                       tr("<h2>%1 Client %2</h2>").arg(getBrand()).arg(
-                           STRINGIZE(SEAFILE_CLIENT_VERSION))
-#if defined(SEAFILE_CLIENT_REVISION)
-                       .append("<h4> REV %1 </h4>")
-                       .arg(STRINGIZE(SEAFILE_CLIENT_REVISION))
-#endif
-                       );
+    if (!about_dialog_) {
+        about_dialog_ = new AboutDialog();
+    }
+    about_dialog_->show();
+    about_dialog_->raise();
+    about_dialog_->activateWindow();
+    return;
+
+//     QMessageBox::about(seafApplet->mainWindow(), tr("About %1").arg(getBrand()),
+//                        tr("<h2>%1 Client %2</h2>").arg(getBrand()).arg(
+//                            STRINGIZE(SEAFILE_CLIENT_VERSION))
+// #if defined(SEAFILE_CLIENT_REVISION)
+//                        .append("<h4> REV %1 </h4>")
+//                        .arg(STRINGIZE(SEAFILE_CLIENT_REVISION))
+// #endif
+//                        );
 }
 
 void SeafileTrayIcon::openHelp()
@@ -564,13 +563,6 @@ void SeafileTrayIcon::refreshTrayIcon()
         return;
     }
 
-    int n_unread_msg = SeahubNotificationsMonitor::instance()->getUnreadNotifications();
-    if (n_unread_msg > 0) {
-        setState(STATE_HAVE_UNREAD_MESSAGE,
-                 tr("You have %n message(s)", "", n_unread_msg));
-        return;
-    }
-
     if (!seafApplet->settingsManager()->autoSync()) {
         setState(STATE_DAEMON_AUTOSYNC_DISABLED,
                  tr("auto sync is disabled"));
@@ -617,20 +609,6 @@ void SeafileTrayIcon::refreshTrayIconToolTip()
     rotate(true);
 }
 
-void SeafileTrayIcon::onSeahubNotificationsChanged()
-{
-    if (!rotate_timer_->isActive()) {
-        refreshTrayIcon();
-    }
-}
-
-void SeafileTrayIcon::viewUnreadNotifications()
-{
-    SeahubNotificationsMonitor::instance()->openNotificationsPageInBrowser();
-    refreshTrayIcon();
-}
-
-
 void SeafileTrayIcon::onMessageClicked()
 {
     if (repo_id_.isEmpty())
@@ -665,7 +643,6 @@ void SeafileTrayIcon::checkTrayIconMessageQueue()
 
 void SeafileTrayIcon::showSyncErrorsDialog()
 {
-    // CloneTasksDialog dialog(this);
     if (sync_errors_dialog_ == nullptr) {
         sync_errors_dialog_ = new SyncErrorsDialog;
     }
