@@ -797,3 +797,64 @@ QByteArray buildFormData(const QHash<QString, QString>& params)
     return u.encodedQuery();
 #endif
 }
+
+int digitalCompare(const QString &left, const QString &right)
+{
+    int ret = 0;
+    if (left.compare(right) == 0)
+        return ret;
+    if (left.size() == 0)
+        return -1;
+    if (right.size() == 0)
+        return 1;
+
+    QString left_sub = left;
+    QString right_sub = right;
+    const uint min_size = left.size() < right.size()
+                          ? left.size() : right.size();
+    uint i;
+    for (i = 0; i != min_size; i++) {
+        if (left[i].isDigit() && right[i].isDigit())
+            break;
+        if (left[i] != right[i])
+            return left.compare(right);
+    }
+    left_sub = left_sub.right(left_sub.size() - i);
+    right_sub = right_sub.right(right_sub.size() - i);
+
+    const QRegExp left_digit_pattern("(\\d+)*");
+    const QRegExp right_digit_pattern("(\\d+)*");
+    const int left_pos = left_digit_pattern.indexIn(left_sub);
+    const int right_pos = right_digit_pattern.indexIn(right_sub);
+    if (left_pos == 0 && right_pos == 0) {
+        quint64 left_digit = left_digit_pattern.cap(1).toUInt();
+        quint64 right_digit = right_digit_pattern.cap(1).toUInt();
+        if (left_digit == right_digit) {
+            left_sub = left_sub.right(left_sub.size() -
+                                      left_digit_pattern.cap(1).size());
+            right_sub = right_sub.right(right_sub.size() -
+                                        right_digit_pattern.cap(1).size());
+            return digitalCompare(left_sub, right_sub);
+        }
+        return left_digit - right_digit;
+    }
+    return left.compare(right);
+}
+
+bool shouldUseFramelessWindow()
+{
+    static int _shouldUseFramelessWindow = -1;
+
+    if (_shouldUseFramelessWindow < 0) {
+        _shouldUseFramelessWindow = 1;
+#if defined(Q_OS_MAC)
+        _shouldUseFramelessWindow = 0;
+#elif defined(Q_OS_WIN32)
+        if (utils::win::isWindows10OrHigher()) {
+            _shouldUseFramelessWindow = 0;
+        }
+#endif
+    }
+
+    return _shouldUseFramelessWindow > 0;
+}
